#! /bin/sh
#
# skeleton	example file to build /etc/init.d/ scripts.
#		This file should be used to construct scripts for /etc/init.d.
#
#		Written by Miquel van Smoorenburg <miquels@cistron.nl>.
#		Modified for Debian GNU/Linux
#		by Ian Murdock <imurdock@gnu.ai.mit.edu>.
#
# Version:	@(#)skeleton  1.8a  10-May-2004 wfreitag@ii3.com
#
# This file was automatically customized by dh-make on Mon, 17 Jan 2000 19:30:36 +0000
# Hacked into netsaint shape by bjb.
# Hacked even further by Warren Freitag of ii3 inc. (Toronto, Canada) to
# conform to default installation of source tarball on a Debian Sarge system.

PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
NAGIOS_PATH=/usr/local/nagios
DAEMON=$NAGIOS_PATH/bin/nagios
NAME=nagios
DESC=nagios
NICENESS=5
NAMEDPIPE=/usr/local/nagios/var/rw/nagios.cmd

test -f $DAEMON || exit 0

set -e

check_started () {
    if [ -f $NAGIOS_PATH/plugins/check_nagios ]; then
	if $NAIGIOS_PATH/plugins/check_nagios -F /var/log/nagios/status.log -e 5 -C 'nagios' > /dev/null; then
	    return 0    # Is started
	else
	    return 1    # Isn't started
	fi
    else
	# Old fashioned way - using ps
	# This is most likley broken, but it's something!
	PS=`/bin/ps axwww | grep nagios | grep -v grep`
	if [ ! -s "$PS" ]; then
	    return 1    # Isn't started
	else
	    return 0    # Is started
	fi
    fi
}

get_config () {
    set -- `grep ^$1 $NAGIOS_PATH/etc/nagios.cfg | sed 's@=@ @'`
    echo $2
}

check_config () {
    if $DAEMON -v $NAGIOS_PATH/etc/nagios.cfg >/dev/null 2>&1 ; then
	return 0    # Config is ok
    else
	return 1    # Config not ok
    fi
}

check_named_pipe () {
    if [ -p $NAMEDPIPE ]; then
	return 1   # a named pipe exists
    else
	return 0   # no named pipe exists
    fi
}

case "$1" in
  start)
	echo -n "Starting $DESC: "
	if ! check_started; then
	    if ! check_named_pipe; then
		echo "named pipe exists - removeing"
		rm -f $NAMEDPIPE
	    fi

	    if check_config; then
		rm -f /var/cache/nagios/rw/nagios.cmd
		nice -$NICENESS \
		    start-stop-daemon --start --quiet \
		    --pidfile /var/run/$NAME.pid \
		    --make-pidfile --background --exec $DAEMON -- -d $NAGIOS_PATH/etc/nagios.cfg
		echo "$NAME."
	    else
		echo "errors in config!"
	    fi
	else
	    echo "already running"
	fi
	;;
  stop)
	echo -n "Stopping $DESC: "
	# wfreitag: added this as a workaround because the pidfile
	# never seems to contain the right process id
	killall $NAME
#	start-stop-daemon --stop --quiet --pidfile /var/run/$NAME.pid \
#		--oknodo --exec $DAEMON
	echo "$NAME."
	rm -f /var/run/$NAME.pid
	rm -f /var/cache/nagios/rw/nagios.cmd
	;;
  reload|force-reload)
	echo "Reloading $DESC configuration files."
	# Check first
	if check_config; then
	    if check_started; then
		start-stop-daemon --stop --signal 1 --quiet --pidfile \
		    /var/run/$NAME.pid --exec $DAEMON
	    else
		echo "Not running."
	    fi
	else
	    echo "Errors in config file. Not reloading."
	fi
  	;;
  restart)
	echo -n "Restarting $DESC: "
	if check_started; then
	    if ! check_named_pipe; then
		echo "named pipe exists - removeing"
		rm -f $NAMEDPIPE
	    fi

	    if check_config; then
		#start-stop-daemon --stop --quiet --pidfile /var/run/$NAME.pid \
		#	--oknodo --exec $DAEMON || true
		# wfreitag: added this as a workaround because the pidfile
		# never seems to contain the right process id
		killall $NAME
		sleep 2

		nice -$NICENESS \
		    start-stop-daemon --start --quiet \
			--pidfile /var/run/$NAME.pid --background --make-pidfile \
			--exec $DAEMON -- $NAGIOS_PATH/etc/nagios.cfg
		echo "$NAME."
	    else
		echo "Errors in config file. Not restarting."
	    fi
	else
	    echo "Not running; starting."
	    exec $0 start
	fi
	;;
  *)
	N=/etc/init.d/$NAME
	echo "Usage: $N {start|stop|restart|reload|force-reload}" >&2
	exit 1
	;;
esac

exit 0
